==> jc-1.4.0.tar.gz: soot/jimple/spark/builder/MethodNodeFactory__241.h <==
// class soot.jimple.spark.builder.MethodNodeFactory$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d048eaf64ce6dc1a soot_jimple_AbstractStmtSwitch
// @dep_class 45bf0e15370018cb soot_jimple_spark_builder_MethodNodeFactory__241

// header file dependencies
// @dep_header soot_jimple_AbstractStmtSwitch

#include "soot/jimple/AbstractStmtSwitch.h"

#ifndef _JC_soot_jimple_spark_builder_MethodNodeFactory__241_H_
#define _JC_soot_jimple_spark_builder_MethodNodeFactory__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_AssignStmt$object;
struct _jc_soot_jimple_IdentityStmt$object;
struct _jc_soot_jimple_ReturnStmt$object;
struct _jc_soot_jimple_ThrowStmt$object;
struct _jc_soot_jimple_spark_builder_MethodNodeFactory$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$object;

typedef const struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods;
typedef const struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable;
typedef const struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype;

// Constructors
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$_init$e0ddba7356b2bf8e(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseAssignStmt$de19a495d79e10c8(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseIdentityStmt$e3924139c5cc4e36(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseReturnStmt$1559ca8208411026(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseThrowStmt$f52f1c60cb1132a4(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseAssignStmt$de19a495d79e10c8;
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseIdentityStmt$e3924139c5cc4e36;
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseReturnStmt$1559ca8208411026;
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseThrowStmt$f52f1c60cb1132a4;

// Virtual methods structure
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods {
	void	(*caseAssignStmt$de19a495d79e10c8)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
	void	(*caseIdentityStmt$e3924139c5cc4e36)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
	void	(*caseReturnStmt$1559ca8208411026)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
	void	(*caseThrowStmt$f52f1c60cb1132a4)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractStmtSwitch$vmethods	soot_jimple_AbstractStmtSwitch;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods	soot_jimple_spark_builder_MethodNodeFactory__241;
};

// Vtype
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs {
	struct _jc_soot_jimple_spark_builder_MethodNodeFactory$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs {
    _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs	soot_jimple_spark_builder_MethodNodeFactory__241;
    _jc_soot_jimple_AbstractStmtSwitch$sub_refs	soot_jimple_AbstractStmtSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractStmtSwitch$sub_nonrefs	soot_jimple_AbstractStmtSwitch;
    _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs	soot_jimple_spark_builder_MethodNodeFactory__241;
};

// Object instance structure
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object {
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype	*vtype;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype _jc_soot_jimple_spark_builder_MethodNodeFactory__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_builder_MethodNodeFactory__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_builder_MethodNodeFactory__241$class_object;

#endif	/* _JC_soot_jimple_spark_builder_MethodNodeFactory__241_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/builder/MethodNodeFactory__241.h <==
// class soot.jimple.spark.builder.MethodNodeFactory$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d048eaf64ce6dc1a soot_jimple_AbstractStmtSwitch
// @dep_class 45bf0e15370018cb soot_jimple_spark_builder_MethodNodeFactory__241

// header file dependencies
// @dep_header soot_jimple_AbstractStmtSwitch

#include "soot/jimple/AbstractStmtSwitch.h"

#ifndef _JC_soot_jimple_spark_builder_MethodNodeFactory__241_H_
#define _JC_soot_jimple_spark_builder_MethodNodeFactory__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_AssignStmt$object;
struct _jc_soot_jimple_IdentityStmt$object;
struct _jc_soot_jimple_ReturnStmt$object;
struct _jc_soot_jimple_ThrowStmt$object;
struct _jc_soot_jimple_spark_builder_MethodNodeFactory$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs;
typedef struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$object;

typedef const struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods;
typedef const struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable;
typedef const struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype;

// Constructors
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$_init$e0ddba7356b2bf8e(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseAssignStmt$de19a495d79e10c8(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseIdentityStmt$e3924139c5cc4e36(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseReturnStmt$1559ca8208411026(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method$caseThrowStmt$f52f1c60cb1132a4(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseAssignStmt$de19a495d79e10c8;
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseIdentityStmt$e3924139c5cc4e36;
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseReturnStmt$1559ca8208411026;
extern _jc_method _jc_soot_jimple_spark_builder_MethodNodeFactory__241$method_info$caseThrowStmt$f52f1c60cb1132a4;

// Virtual methods structure
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods {
	void	(*caseAssignStmt$de19a495d79e10c8)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseIdentityStmt$e3924139c5cc4e36)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseReturnStmt$1559ca8208411026)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseThrowStmt$f52f1c60cb1132a4)(_jc_env *, struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractStmtSwitch$vmethods	soot_jimple_AbstractStmtSwitch;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vmethods	soot_jimple_spark_builder_MethodNodeFactory__241;
};

// Vtype
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs {
	struct _jc_soot_jimple_spark_builder_MethodNodeFactory$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs {
    _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_refs	soot_jimple_spark_builder_MethodNodeFactory__241;
    _jc_soot_jimple_AbstractStmtSwitch$sub_refs	soot_jimple_AbstractStmtSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractStmtSwitch$sub_nonrefs	soot_jimple_AbstractStmtSwitch;
    _jc_soot_jimple_spark_builder_MethodNodeFactory__241$sub_nonrefs	soot_jimple_spark_builder_MethodNodeFactory__241;
};

// Object instance structure
struct _jc_soot_jimple_spark_builder_MethodNodeFactory__241$object {
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype	*vtype;
	_jc_soot_jimple_spark_builder_MethodNodeFactory__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_builder_MethodNodeFactory__241$vtype _jc_soot_jimple_spark_builder_MethodNodeFactory__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_builder_MethodNodeFactory__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_builder_MethodNodeFactory__241$class_object;

#endif	/* _JC_soot_jimple_spark_builder_MethodNodeFactory__241_H_ */
